import { html, repeat } from '@microsoft/fast-element';
export const DesignSystemEditorTemplate = html `
  <template>
    <div class="configuration">
      <div class="row" id="designSystem">
        <div class="label">
          <label for="body-font">Design System</label>
        </div>
        <div class="input">
          <alpha-select name="ds" @change="${(x, c) => x.changeHandler(c.event)}">
            ${repeat((x) => x.designSystems, html `
                <alpha-option value="${(x) => x.value}">${(x) => x.name}</alpha-option>
              `)}
          </alpha-select>
        </div>
      </div>
      <div class="row" id="color">
        <div class="label">
          <label for="accent-color-pickers">Accent color</label>
        </div>
        <div class="color-input-row">
          <input
            name="accentColor"
            type="color"
            :value="${(x) => x.accentColor}"
            @input="${(x, c) => x.changeHandler(c.event)}"
          />
          <alpha-text-field
            name="accentColor"
            type="text"
            :value="${(x) => x.accentColor}"
            @input="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-text-field>
        </div>
      </div>

      <div class="row" id="color">
        <div class="label">
          <label for="neutral-color-pickers">Neutral color</label>
        </div>
        <div class="color-input-row">
          <input
            name="neutralColor"
            type="color"
            :value="${(x) => x.neutralColor}"
            @input="${(x, c) => x.changeHandler(c.event)}"
          />
          <alpha-text-field
            name="neutralColor"
            type="text"
            :value="${(x) => x.neutralColor}"
            @input="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-text-field>
        </div>
      </div>

      <div class="row" id="bodyfont">
        <div class="label">
          <label for="body-font">Body Font</label>
        </div>
        <div class="input">
          <alpha-combobox
            name="bodyFont"
            autocomplete="both"
            :value="${(x) => x.bodyFont}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          >
            <alpha-option value="Roboto">Roboto</alpha-option>
            <alpha-option value="Segoe UI">Segoe UI</alpha-option>
            <alpha-option value="Monospace">Monospace</alpha-option>
            <alpha-option value="Times New Roman">Times New Roman</alpha-option>
            <alpha-option value="Helvetica">Helvetica</alpha-option>
            <alpha-option value="Garamond">Garamond</alpha-option>
            <alpha-option value="Georgia">Georgia</alpha-option>
            <alpha-option value="Verdana">Verdana</alpha-option>
          </alpha-combobox>
        </div>
      </div>

      <div class="row" id="baseFontSize">
        <div class="label">
          <label for="base-font-size">Base Font Size</label>
        </div>
        <div class="input">
          <alpha-combobox
            name="baseFontSize"
            autocomplete="both"
            :value="${(x) => x.baseFontSize}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          >
            <alpha-option value="8px">8px</alpha-option>
            <alpha-option value="10px">10px</alpha-option>
            <alpha-option value="12px">12px</alpha-option>
            <alpha-option value="14px">14px</alpha-option>
            <alpha-option value="16px">16px</alpha-option>
            <alpha-option value="20px">20px</alpha-option>
            <alpha-option value="24px">24px</alpha-option>
          </alpha-combobox>
        </div>
      </div>

      <div class="row" id="baseLineHeight">
        <div class="label">
          <label for="base-line-height">Base Line Height</label>
        </div>
        <div class="input">
          <alpha-combobox
            name="baseLineHeight"
            autocomplete="both"
            :value="${(x) => x.baseLineHeight}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          >
            <alpha-option value="12px">12px</alpha-option>
            <alpha-option value="14px">14px</alpha-option>
            <alpha-option value="16px">16px</alpha-option>
            <alpha-option value="20px">20px</alpha-option>
            <alpha-option value="24px">24px</alpha-option>
            <alpha-option value="28px">28px</alpha-option>
          </alpha-combobox>
        </div>
      </div>

      <div class="row" id="darkmode">
        <div class="label">
          <label for="dark-mode-switch">Dark mode</label>
        </div>
        <div class="input">
          <alpha-switch
            name="darkMode"
            :checked="${(x) => x.darkMode}"
            @change="${(x, c) => x.modeChangeHandler(c.event)}
                "
          >
            <span slot="checked-message">On</span>
            <span slot="unchecked-message">Off</span>
          </alpha-switch>
        </div>
      </div>

      <div class="row">
        <div class="label">
          <label for="density-slider">Density</label>
        </div>
        <div class="input">
          <alpha-slider
            name="density"
            min="-3"
            max="3"
            step="1"
            :value="${(x) => x.density}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-slider>
        </div>
      </div>

      <div class="row">
        <div class="label">
          <label for="design-unit-slider">Design Unit</label>
        </div>
        <div class="input">
          <alpha-slider
            name="designUnit"
            min="1"
            max="10"
            step="1"
            :value="${(x) => x.designUnit}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-slider>
        </div>
      </div>

      <div class="row">
        <div class="label">
          <label for="border-radius-slider">Border radius</label>
        </div>
        <div class="input">
          <alpha-slider
            name="borderRadius"
            min="0"
            max="20"
            step="1"
            :value="${(x) => x.borderRadius}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-slider>
        </div>
      </div>

      <div class="row">
        <div class="label">
          <label for="stroke-width-slider">Stroke width</label>
        </div>
        <div class="input">
          <alpha-slider
            name="strokeWidth"
            min="1"
            max="4"
            step="1"
            :value="${(x) => x.strokeWidth}"
            @change="${(x, c) => x.changeHandler(c.event)}"
          ></alpha-slider>
        </div>
      </div>
      <div class="footer-row">
        <alpha-button appearance="accent" @click="${(x) => x.resetChanges()}">Reset</alpha-button>
        <slot name="export"></slot>
      </div>
    </div>

    <div class="preview">
      <slot></slot>
    </div>
  </template>
`;
